pub struct Code {
pub inner: u32,
}Fields
inner: u32Trait Implementations
Sourceimpl Error for Code
Available on crate features err_code and err only.
impl Error for Code
Available on crate features
err_code and err only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl Message for Code
impl Message for Code
Sourcefn descriptor(&self) -> Option<MessageDescriptor>
fn descriptor(&self) -> Option<MessageDescriptor>
Returns the
MessageDescriptor for this message, if this is not a primitive type.Sourcefn compute_size(&self) -> usize
fn compute_size(&self) -> usize
Computes the number of bytes a message will take when serialized. This does not
include number of bytes required for tag+wire_format or the bytes used to represent
length of the message in case of LengthDelimited messages/types.
Sourcefn serialize<W: PbBufferWriter>(&self, w: &mut W) -> Result<()>
fn serialize<W: PbBufferWriter>(&self, w: &mut W) -> Result<()>
Serializes the message to the writer.
Sourcefn deserialize<B: PbBufferReader>(&mut self, buf: &mut B) -> Result<()>
fn deserialize<B: PbBufferReader>(&mut self, buf: &mut B) -> Result<()>
Reads the message from the blob reader, copying as necessary.
Sourcefn compute_grpc_slices_size(&self) -> usize
fn compute_grpc_slices_size(&self) -> usize
Computes the number of bytes in all grpc slices.
This information is used to optimize memory allocations in zero-copy encoding.
Sourceimpl Ord for Code
impl Ord for Code
Sourceimpl PartialOrd for Code
impl PartialOrd for Code
Sourceimpl Reflection for Code
impl Reflection for Code
impl Copy for Code
impl Eq for Code
impl StructuralPartialEq for Code